@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0+   2011/02/14
+ * Version: 1.8.1   2011/04/01
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -19,6 +19,32 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 #include "include.h"
+#include <linux/elf.h>
+
+static void make_elf_lib(void)
+{
+	static const struct elf32_phdr eph = {
+		.p_type = PT_LOAD,
+		.p_offset = 4096,
+		.p_filesz = 1,
+	};
+	static const struct elf32_hdr eh = {
+		.e_ident = ELFMAG,
+		.e_type = ET_EXEC,
+		.e_machine = EM_386,
+		.e_phoff = sizeof(eh),
+		.e_phentsize = sizeof(eph),
+		.e_phnum = 1,
+	};
+	const int fd = open("/tmp/uselib", O_WRONLY | O_CREAT | O_TRUNC, 0755);
+	if (fd != EOF) {
+		write(fd, &eh, sizeof(eh));
+		write(fd, &eph, sizeof(eph));
+		lseek(fd, 4096, SEEK_SET);
+		write(fd, "", 1);
+		close(fd);
+	}
+}
 
 static const char *policy = "";
 
@@ -151,12 +177,12 @@ static void stage_file_test(void)
 	write_domain_policy(policy, 1);
 	show_result(sysctl(name, 3, buffer, &size, buffer, size), 0);
 
-	policy = "file read /bin/true "
+	policy = "file read /tmp/uselib "
 		"path1.uid=0 path1.parent.uid=0 10=10-100";
 	write_domain_policy(policy, 0);
-	show_result(uselib("/bin/true"), 1);
+	show_result(uselib("/tmp/uselib"), 1);
 	write_domain_policy(policy, 1);
-	show_result(uselib("/bin/true"), 0);
+	show_result(uselib("/tmp/uselib"), 0);
 
 	policy = "file execute /bin/true task.uid!=10 path1.parent.uid=0";
 	write_domain_policy(policy, 0);
@@ -277,7 +303,8 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "file read/write /tmp/fifo path1.type=fifo";
+	policy = "file read /tmp/fifo path1.type=fifo\t"
+		"file write /tmp/fifo path1.type=fifo";
 	mkfifo2("/tmp/fifo");
 	write_domain_policy(policy, 0);
 	fd = open("/tmp/fifo", O_RDWR);
@@ -314,7 +341,8 @@ static void stage_file_test(void)
 	if (fd != EOF)
 		close(fd);
 
-	policy = "file read/write /dev/null task.uid=path1.parent.uid";
+	policy = "file read /dev/null task.uid=path1.parent.uid\t"
+		"file write /dev/null task.uid=path1.parent.uid";
 	write_domain_policy(policy, 0);
 	fd = open("/dev/null", O_RDWR);
 	show_result(fd, 1);
@@ -594,6 +622,7 @@ static void stage_file_test(void)
 int main(int argc, char *argv[])
 {
 	ccs_test_init();
+	make_elf_lib();
 	fprintf(domain_fp, "%s /bin/true\n", self_domain);
 	fprintf(domain_fp, "use_profile 255\n");
 	fprintf(domain_fp, "select pid=%u\n", pid);
